/*
 * Copyright 2009-2014 Odin Hørthe Omdal
 *
 * This file is part of Medlemssys.
 *
 * Medlemssys is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Medlemssys is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Medlemssys.  If not, see <http://www.gnu.org/licenses/>.
 */
.ikkje-teljande { color: #f00; }
.er-gamal { color: #850; }

.field-kid input { width: 8em; }
.field-desc .vLargeTextField {
    width: 90%;
    height: 2em;
}
