<!doctype html>
<meta charset=utf-8>
<title>Vervetopp</title>

<style type=text/css>
    body { font-family: "Arial", "Helvetica", sans-serif; line-height: 1.5em; font-size: 8pt; max-width: 800px; }
    .info {
        text-align: right;
        padding: 0;
        margin: 0;
    }
    .info li {
        display: inline-block;
        font-size: 0.8em;
        margin: 0 1em;
    }
    .betalt, .ubetalt, .andre {
        color: rgba(255, 255, 255, 0.1);
        display: inline-block;
        font-family: monospace;
        margin: 0;
        padding: 0 2px;
    }
    .betalt { background-color: #5D927D; }
    .ubetalt { background-color: #bbc6bb; }
    .andre { background-color: rgb(228, 179, 179); }

    tr:nth-child(even) { background-color: #f6f6f6; }
</style>

<ul class=info>
  <li><span class=betalt>B</span> betalt
  <li><span class=ubetalt>u</span> ikkje betalt
  <li><span class=andre>×</span> ikkje teljande
</ul>

{% if not objects %}
<p><strong>Ingen har verva nokon enno, skund deg, so vert du den fyrste.</strong></p>
{% else %}
<table><thead><tr><th>Vervar <th>Vervingar</tr></thead>
    <colgroup><col style="width: 40%"></colgroup>
    <tbody>
    {% for o in objects %}
        <tr><td>{{ o.0 }} <td>{% spaceless %}
            {% for v in o.1 %}<span class=betalt>B</span>{% endfor %}
            {% for v in o.2 %}<span class=ubetalt>u</span>{% endfor %}
            {% for v in o.3 %}<span class=andre>×</span>{% endfor %}
            {% endspaceless %}
            <!-- {{ o }} -->
            </td>
        </tr>
    {% endfor %}
    </tbody>
</table>
{% endif %}
<p><small>Oppdaterast kvar arbeidsdag.</small></p>
