{% extends "admin/base_site.html" %}
{% load i18n l10n admin_static %}
{% block extrastyle %}{{ block.super }}<link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}">
<style>
table ul { padding: 0 0 0 1em; }
.error { color: #990000; }
</style>
{% endblock %}

{% block breadcrumbs %}
<div class="breadcrumbs">
     <a href="../../../">{% trans "Home" %}</a> &rsaquo;
     <a href="../">Giro</a> &rsaquo;
     {% trans "Send ventande giroar" %}
</div>
{% endblock %}
