{% extends "admin/base_site.html" %}
{% load i18n l10n %}

{% block breadcrumbs %}
<div class="breadcrumbs">
     <a href="../../">{% trans "Home" %}</a> &rsaquo;
     <a href="../">{{ app_label|capfirst }}</a> &rsaquo;
     <a href="./">{{ opts.verbose_name_plural|capfirst }}</a> &rsaquo;
     {% trans "PDF-info" %}
</div>
{% endblock %}

{% block content %}
    <form action="" method="post">{% csrf_token %}
    <label>Tittel <input type=text name=title></label>
    <label>Tekst <textarea name="text"></textarea></label>
    {% for obj in queryset %}
    <input type="hidden" name="{{ action_checkbox_name }}" value="{{ obj.pk|unlocalize }}" />
    {% endfor %}
    <input type="hidden" name="action" value="pdf_member_list" />
    <input type="hidden" name="post" value="yes" />
    <input type="submit" value="{% trans "Yes, I'm sure" %}" />
    </form>
{% endblock %}
